@@ -4,7 +4,6 @@ import json
 
 class BaseItem(scrapy.Item):
     crawled_at = scrapy.Field()
-    oss_filename = scrapy.Field()
     unique_id = scrapy.Field()
 
     def to_dict(self):
@@ -13,6 +12,3 @@ class BaseItem(scrapy.Item):
 
     def to_json_str(self):
         return json.dumps(self.to_dict(), ensure_ascii=False)
-
-    def queue_names(self):
-        return []
\ No newline at end of file
