@@ -2,7 +2,6 @@ import scrapy
 import json
 from scrapy_nc.item import BaseItem
 
-
 class NewsItem(BaseItem):
     url = scrapy.Field()
     title = scrapy.Field()
@@ -29,8 +28,8 @@ class NewsItem(BaseItem):
         return dt
 
     def to_json_str(self):
-        if not self['publish_date'] == None:
+        if self.get('publish_date') is not None:
             self['publish_date'] = self['publish_date'].isoformat()
-        if not self['crawled_date'] == None:
+        if self['crawled_date'] is not None:
             self['crawled_date'] = self['crawled_date'].isoformat()
         return json.dumps(self.to_dict(), ensure_ascii=False)
\ No newline at end of file
